FirebaseAnalyticsProvider class

Firebase Analytics Provider with intelligent error handling

Automatically categorizes errors as fatal or non-fatal based on:

  • Error type (OutOfMemoryError, critical system errors = fatal)
  • Source library (engine/flutter core errors may be fatal)
  • Error context (UI errors, widget errors = non-fatal)
Inheritance
  • Object
  • LogProvider
  • FirebaseAnalyticsProvider

Constructors

FirebaseAnalyticsProvider([FirebaseApp? _providedFirebaseApp])
Creates a Firebase analytics provider.

Properties

ensembleAppId String?
getter/setter pairinherited
firebaseOptions ↔ FirebaseOptions?
Firebase options resolved from the Ensemble configuration.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
options Map?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldAwait bool
getter/setter pairinherited

Methods

convertMap(Map<String, dynamic> input) Map<String, Object>
Converts non-null dynamic map values into Firebase parameter values.
init({Map? options, String? ensembleAppId, bool shouldAwait = false}) Future<void>
Initializes Firebase Analytics and Crashlytics error handling.
override
log(Map<String, dynamic> config) Future<void>
Handles an Ensemble logging configuration payload.
override
logEvent(String event, Map<String, dynamic> parameters, LogLevel level) Future<void>
Logs a Firebase Analytics event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserId(String userId) Future<void>
Sets the Firebase Analytics user identifier.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited